
%global		_hardened_build 1

Name:		libntirpc
Version:	1.8.0
Release:	1%{?dev:%{dev}}%{?dist}
Summary:	New Transport Independent RPC Library
Group:		System Environment/Libraries
License:	BSD
Url:		https://github.com/nfs-ganesha/ntirpc

Source0:	https://github.com/nfs-ganesha/ntirpc/archive/v%{version}/ntirpc-%{version}.tar.gz

BuildRequires:	cmake
BuildRequires:	krb5-devel
BuildRequires:  userspace-rcu-devel
%if ( 0%{?fedora} && 0%{?fedora} > 27 ) || 0%{?rhel} >= 8
BuildRequires:  libnsl2-devel
%endif
# libtirpc has /etc/netconfig, most machines probably have it anyway
# for NFS client
Requires:	libtirpc

ExcludeArch:	ppc

%description
This package contains a new implementation of the original libtirpc, 
transport-independent RPC (TI-RPC) library for NFS-Ganesha. It has
the following features not found in libtirpc:
 1. Bi-directional operation
 2. Full-duplex operation on the TCP (vc) transport
 3. Thread-safe operating modes
 3.1 new locking primitives and lock callouts (interface change)
 3.2 stateless send/recv on the TCP transport (interface change)
 4. Flexible server integration support
 5. Event channels (remove static arrays of xprt handles, new EPOLL/KEVENT
    integration)

%package devel
Summary:	Development headers for %{name}
Requires:	%{name}%{?_isa} = %{version}

%description devel
Development headers and auxiliary files for developing with %{name}.

%prep
%setup -q -n ntirpc-%{version}

%build
%cmake . -DOVERRIDE_INSTALL_PREFIX=/usr -DTIRPC_EPOLL=1 -DUSE_GSS=ON "-GUnix Makefiles"

make %{?_smp_mflags}

%install
## make install is broken in various ways
## make install DESTDIR=%%{buildroot}
mkdir -p %{buildroot}%{_libdir}/pkgconfig
install -p -m 0755 src/%{name}.so.%{version} %{buildroot}%{_libdir}/
ln -s %{name}.so.%{version} %{buildroot}%{_libdir}/%{name}.so.1
ln -s %{name}.so.%{version} %{buildroot}%{_libdir}/%{name}.so
mkdir -p %{buildroot}%{_includedir}/ntirpc
cp -a ntirpc %{buildroot}%{_includedir}/
install -p -m 644 libntirpc.pc %{buildroot}%{_libdir}/pkgconfig/

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%{_libdir}/libntirpc.so.*
%{!?_licensedir:%global license %%doc}
%license COPYING
%doc NEWS README

%files devel
%{_libdir}/libntirpc.so
%dir %{_includedir}/ntirpc
%{_includedir}/ntirpc/*
%{_libdir}/pkgconfig/libntirpc.pc

%changelog
* Fri Jul 19 2019 Thomas Serlin <tserlin@redhat.com> 1.8.0-1
- Update to 1.8.0

* Fri Jun 07 2019 Thomas Serlin <tserlin@redhat.com> 1.7.4-1
- Update to 1.7.4 (rhbz#1700896)

* Fri Apr 12 2019 Thomas Serlin <tserlin@redhat.com> 1.7.3-1
- Update to 1.7.3 (rhbz#1699219)

* Fri Oct 19 2018 Thomas Serlin <tserlin@redhat.com> 1.7.1-1
- Update to 1.7.1 (rhbz#1593000)

* Thu Sep 27 2018 Thomas Serlin <tserlin@redhat.com> 1.7.0-1
- Update to 1.7.0 (rhbz#1593000)

* Fri Mar 09 2018 Thomas Serlin <tserlin@redhat.com> 1.5.5-1
- Update to 1.5.5 (rhbz#1553302)

* Thu Jul 20 2017 Ken Dreyer <kdreyer@redhat.com> - 1.5.3-1
- update to 1.5.3 (rhbz#1473386)

* Mon May 8 2017 Kaleb S. KEITHLEY <kkeithle at redhat.com> 1.4.3-2
- Resolves: rhbz#1449310 (originally, rhbz#1448862)

* Wed Nov 2 2016 Kaleb S. KEITHLEY <kkeithle at redhat.com> 1.4.3-1
- libntirpc-1.4.3
- Resolves: rhbz#1389468

* Tue Sep 20 2016 Kaleb S. KEITHLEY <kkeithle at redhat.com> 1.4.1-1
- libntirpc-1.4.1
- Resolves: rhbz#1357847

* Mon Sep 19 2016 Kaleb S. KEITHLEY <kkeithle at redhat.com> 1.4.0-1
- libntirpc-1.4.0
- Resolves: rhbz#1357847

* Tue Mar 22 2016 Kaleb S. KEITHLEY <kkeithle at redhat.com> 1.3.1-1
- Initial commit, libntirpc-1.3.1 (#1318506)
